// CkGzip.h: interface for the CkGzip class.
//
//////////////////////////////////////////////////////////////////////

#if !defined(_CK_GZIP_H)
#define _CK_GZIP_H

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

#include "CkObject.h"

class CkString;
class CkByteData;

// CLASS: CkGzip
class CkGzip  : public CkObject 
{
public:
    private:
	void *m_impl;
	bool m_utf8;	// If true, all input "const char *" parameters are utf-8, otherwise they are ANSI strings.

	// Don't allow assignment or copying these objects.
	CkGzip(const CkGzip &) { } 
	CkGzip &operator=(const CkGzip &) { return *this; }

    public:
	void *getImpl(void) { return m_impl; } 

	CkGzip(void *impl);

	CkGzip();
	virtual ~CkGzip();

	// BEGIN PUBLIC INTERFACE
	bool get_Utf8(void) const;
	void put_Utf8(bool b);

	// Error log retrieval and saving (these methods are common to all Chilkat VC++ classes.)
	bool SaveLastError(const char *filename);
        void LastErrorXml(CkString &str);
        void LastErrorHtml(CkString &str);
        void LastErrorText(CkString &str);

	bool UnlockComponent(const char *unlockCode);
	bool IsUnlocked(void) const;


	// File-to-file
	bool CompressFile(const char *inFilename, const char *outFilename);
	bool UncompressFile(const char *inFilename, const char *outFilename);

	// File-to-memory
	bool CompressFileToMem(const char *inFilename, CkByteData &db);
	bool UncompressFileToMem(const char *inFilename, CkByteData &db);

	// Memory-to-file
	bool CompressMemToFile(CkByteData &db, const char *outFilename);
	bool UncompressMemToFile(CkByteData &db, const char *outFilename);
	
	// Memory-to-memory
	bool CompressMemory(CkByteData &dbIn, CkByteData &dbOut);
	bool UncompressMemory(CkByteData &dbIn, CkByteData &dbOut);


	void get_Filename(CkString &str);
	void put_Filename(const char *str);

	void get_Comment(CkString &str);
	void put_Comment(const char *str);

	void get_ExtraData(CkByteData &data);
	void put_ExtraData(CkByteData &data);

	void get_LastMod(SYSTEMTIME &sysTime);
	void put_LastMod(SYSTEMTIME &sysTime);


	// END PUBLIC INTERFACE

};

#endif // !defined(_CK_GZIP_H)
